kedro.framework.hooks.specs.DatasetSpecs — Kedro 0.17.6 documentation

# kedro.framework.hooks.specs.DatasetSpecs

class `kedro.framework.hooks.specs.` `DatasetSpecs`

  Namespace that defines all specifications for a dataset’s lifecycle hooks.

  Methods

  `after_dataset_loaded`(dataset_name, data) | Hook to be invoked after a dataset is loaded from the catalog.
  `after_dataset_saved`(dataset_name, data) | Hook to be invoked after a dataset is saved in the catalog.
  `before_dataset_loaded`(dataset_name) | Hook to be invoked before a dataset is loaded from the catalog.
  `before_dataset_saved`(dataset_name, data) | Hook to be invoked before a dataset is saved to the catalog.

  `after_dataset_loaded`(dataset_name, data)

    Hook to be invoked after a dataset is loaded from the catalog.

    Parameters

      - dataset_name (`str`) – name of the dataset that was loaded from the catalog.

      - data (`Any`) – the actual data that was loaded from the catalog.

    Return type

      `None`

  `after_dataset_saved`(dataset_name, data)

    Hook to be invoked after a dataset is saved in the catalog.

    Parameters

      - dataset_name (`str`) – name of the dataset that was saved to the catalog.

      - data (`Any`) – the actual data that was saved to the catalog.

    Return type

      `None`

  `before_dataset_loaded`(dataset_name)

    Hook to be invoked before a dataset is loaded from the catalog.

    Parameters

      dataset_name (`str`) – name of the dataset to be loaded from the catalog.

    Return type

      `None`

  `before_dataset_saved`(dataset_name, data)

    Hook to be invoked before a dataset is saved to the catalog.

    Parameters

      - dataset_name (`str`) – name of the dataset to be saved to the catalog.

      - data (`Any`) – the actual data to be saved to the catalog.

    Return type

      `None`